==> hs-directory-tree-0.2.0p1.tgz: lib/ghc/directory-tree-0.2.0/register.sh <==
#!/bin/sh
echo 'name: directory-tree
version: 0.2.0
id: directory-tree-0.2.0-3b40e4a8211d155916df04c86dbb2747

license: BSD3
copyright: (c) 2010, Brandon Simmons <brandon.m.simmons@gmail.com>
maintainer: Brandon Simmons <brandon.m.simmons@gmail.com>
stability:
homepage: http://coder.bsimmons.name/blog/2009/05/directory-tree-module-released/
package-url:
description: A simple directory-like tree datatype, with useful IO functions and Foldable and Traversable instance
             .
             Provides a simple data structure mirroring a directory tree on the
             filesystem, as well as useful functions for reading and writing
             file and directory structures in the IO monad.
             .
             Importing the library and optional (useful) Foldable and Traverable libraries:
             .
             > import System.Directory.Tree
             > import qualified Data.Foldable as F
             > import qualified Data.Traversable as T
             .
             Write a hand-made directory tree of textfiles (strings) to the disk.
             Simulates creating a new user Tux'\''s home directory on a unix machine:
             .
             > writeDirectory$ "/home" :/ Dir "Tux" [File "README" "Welcome!"]
             .
             "read" a directory by opening all the files at a filepath with readFile,
             returning an '\''AnchoredDirTree String'\'' (d2). Then check for any IO failures:
             .
             > do (base :/ d2) <- readDirectory "../parent_dir/dir2/"
             >    let failed = anyFailed d2
             >    if failed then ...
             .
             Use Foldable instance function to concat a directory '\''dir'\'' of text files into a
             single file under the same directory:
             .
             > do (b :/ dt) <- readDirectory dir
             >    let f = F.concat dt
             >    return$ b :/ File "ALL_TEXT" f
             .
             Open all the files in the current directory as lazy bytestrings, ignoring
             the base path in Anchored wrapper:
             .
             > import qualified Data.ByteString.Lazy as B
             > do (_ :/ dTree) <- readDirectoryWith B.readFile "./"
             .
             Please send me any comments, requests or bug reports
category: Data, System
author: Brandon Simmons
pkgpath: devel/hs-directory-tree
exposed: True
exposed-modules: System.Directory.Tree
hidden-modules:
import-dirs: /usr/local/lib/ghc/directory-tree-0.2.0
library-dirs: /usr/local/lib/ghc/directory-tree-0.2.0
hs-libraries: HSdirectory-tree-0.2.0
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.2.0.2-af431bb15643ef1ce2792a51c33968b3
         directory-1.0.1.1-7962558b34e6144244ddec948ea3bb41
         filepath-1.1.0.4-1425f312faf5b8e9f4babf887e252326
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-directory-tree-0.2.0/html/directory-tree.haddock
haddock-html: /usr/local/share/doc/hs-directory-tree-0.2.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-directory-tree-0.10.0p1.tgz: lib/ghc/directory-tree-0.10.0/register.sh <==
#!/bin/sh
echo 'name: directory-tree
version: 0.10.0
id: directory-tree-0.10.0-361c608061f82ee09b9bf88ef9fd8c4b

license: BSD3
copyright: (c) 2011, Brandon Simmons <brandon.m.simmons@gmail.com>
maintainer: Brandon Simmons <brandon.m.simmons@gmail.com>
stability:
homepage: http://coder.bsimmons.name/blog/2009/05/directory-tree-module-released/
package-url:
synopsis: A simple directory-like tree datatype, with useful IO functions
description: A simple directory-like tree datatype, with useful IO functions and Foldable and Traversable instance
             .
             Provides a simple data structure mirroring a directory tree on the
             filesystem, as well as useful functions for reading and writing
             file and directory structures in the IO monad.
             .
             Importing the library and optional (useful) Foldable and Traverable libraries:
             .
             > import System.Directory.Tree
             > import qualified Data.Foldable as F
             > import qualified Data.Traversable as T
             .
             Write a hand-made directory tree of textfiles (strings) to the disk.
             Simulates creating a new user Tux'\''s home directory on a unix machine:
             .
             > writeDirectory$ "/home" :/ Dir "Tux" [File "README" "Welcome!"]
             .
             "read" a directory by opening all the files at a filepath with readFile,
             returning an '\''AnchoredDirTree String'\'' (d2). Then check for any IO failures:
             .
             > do (base :/ d2) <- readDirectory "../parent_dir/dir2/"
             >    let failed = anyFailed d2
             >    if failed then ...
             .
             Use Foldable instance function to concat a directory '\''dir'\'' of text files into a
             single file under the same directory:
             .
             > do (b :/ dt) <- readDirectory dir
             >    let f = F.concat dt
             >    return$ b :/ File "ALL_TEXT" f
             .
             Open all the files in the current directory as lazy bytestrings, ignoring
             the base path in Anchored wrapper:
             .
             > import qualified Data.ByteString.Lazy as B
             > do (_ :/ dTree) <- readDirectoryWith B.readFile "./"
             .
             This version also offers an experimental function `readDirectoryWithL` that does
             lazy directory IO, allowing you to treat the returned `DirTree` as if it were a
             normal lazily-generated data structure.
             .
             For example, the following does only the amount of IO necessary to list the file
             names of the children of the root directory, similar to "ls /":
             .
             > do d <- readDirectoryWithL readFile "/"
             >    mapM_ (putStrLn . name) $ contents $ free d
             .
             Any ideas or suggestions for improvements are most welcome :-)
             .
category: Data, System
author: Brandon Simmons
pkgpath: devel/hs-directory-tree
exposed: True
exposed-modules: System.Directory.Tree
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/directory-tree-0.10.0
library-dirs: /usr/local/lib/ghc/directory-tree-0.10.0
hs-libraries: HSdirectory-tree-0.10.0
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
         directory-1.1.0.2-da0a8c62c2b42ae7a3b538f5fee58422
         filepath-1.3.0.0-f998e5510c76a98913f57b14b4f16c57
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-directory-tree-0.10.0/html/directory-tree.haddock
haddock-html: /usr/local/share/doc/hs-directory-tree-0.10.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
